@@ -37,8 +37,8 @@ import string
 try:
     from sip4_tqt import sipconfig
 except:
-    print "Unable to import the sipconfig module.  Please make sure you have"
-    print "SIP v3.9 or later installed."
+    print("Unable to import the sipconfig module.  Please make sure you have")
+    print("SIP v3.9 or later installed.")
     sys.exit(1)
 
 config = sipconfig.SIPConfig("PyTQt 3.18.1")
@@ -67,20 +67,20 @@ def usage(rcode = 2):
 
     rcode is the return code passed back to the calling process.
     """
-    print "Usage:"
-    print "    %s [-h] [-a version] [-b dir] [-c] [-d dir] [-g] [-j #] [-n dir] [-o dir] [-r] [-v dir]" % sipconfig.script()
-    print "where:"
-    print "    -h      display this help message"
-    print "    -a tag  explicitly enable the qtpe module"
-    print "    -b dir  where pyuic and pylupdate will be installed [default %s]" % config.default_bin_dir
-    print "    -c      concatenate each module's C++ source files"
-    print "    -d dir  where the PyTQt modules will be installed [default %s]" % config.default_mod_dir
-    print "    -g      always release the GIL (SIP v3.x behaviour)"
-    print "    -j #    split the concatenated C++ source files into # pieces [default 1]"
-    print "    -n dir  the directory containing the TQScintilla header files [default %s]" % config.qt_inc_dir
-    print "    -o dir  the directory containing the TQScintilla library [default %s]" % config.qt_lib_dir
-    print "    -r      generate code with tracing enabled [default disabled]"
-    print "    -v dir  where the PyTQt .sip files will be installed [default %s]" % config.default_sip_dir
+    print("Usage:")
+    print("    %s [-h] [-a version] [-b dir] [-c] [-d dir] [-g] [-j #] [-n dir] [-o dir] [-r] [-v dir]" % sipconfig.script())
+    print("where:")
+    print("    -h      display this help message")
+    print("    -a tag  explicitly enable the qtpe module")
+    print("    -b dir  where pyuic and pylupdate will be installed [default %s]" % config.default_bin_dir)
+    print("    -c      concatenate each module's C++ source files")
+    print("    -d dir  where the PyTQt modules will be installed [default %s]" % config.default_mod_dir)
+    print("    -g      always release the GIL (SIP v3.x behaviour)")
+    print("    -j #    split the concatenated C++ source files into # pieces [default 1]")
+    print("    -n dir  the directory containing the TQScintilla header files [default %s]" % config.qt_inc_dir)
+    print("    -o dir  the directory containing the TQScintilla library [default %s]" % config.qt_lib_dir)
+    print("    -r      generate code with tracing enabled [default disabled]")
+    print("    -v dir  where the PyTQt .sip files will be installed [default %s]" % config.default_sip_dir)
 
     sys.exit(rcode)
 
@@ -439,7 +439,7 @@ def versionToTag(vers, tags, desc):
     """
     tag = None
 
-    vl = tags.keys()
+    vl = list(tags.keys())
     vl.sort()
 
     # For a snapshot use the latest tag.
@@ -689,10 +689,6 @@ def main(argv):
         sipconfig.inform("Creating Makefile for pyuic3.")
         subdirs.append("pyuic3")
         olddir = sipconfig.push_dir("pyuic3")
-    elif config.qt_version >= 0x020000:
-        sipconfig.inform("Creating Makefile for pyuic2.")
-        subdirs.append("pyuic2")
-        olddir = sipconfig.push_dir("pyuic2")
 
     config.create_makefile("pyuic.pro", [])
     sipconfig.pop_dir(olddir)
@@ -723,8 +719,7 @@ if __name__ == "__main__":
     except SystemExit:
         raise
     except:
-        print \
-"""An internal error occured.  Please report all the output from the program,
+        print("""An internal error occured.  Please report all the output from the program,
 including the following traceback, to support@riverbankcomputing.co.uk.
-"""
+""")
         raise
